@@ -52,7 +52,7 @@ class NumerousApp():
         self.result = None
         self.working_folder = working_folder
         if local:
-            self.client = get_client(reset_job=reset_job)
+            self.client = get_client()
         else:
             self.client = NumerousClient()
 
